@@ -1,3 +1,5 @@
+#' @export
+#'
 postprob.lcmm <- function(x,threshold=c(0.7,0.8,0.9),...)
 {
  if (!inherits(x, "lcmm")) stop("use only with \"lcmm\" objects")
@@ -58,5 +60,3 @@ postprob.lcmm <- function(x,threshold=c(0.7,0.8,0.9),...)
  return(invisible(res))
 }
 
-
-postprob <- function(x,threshold=c(0.7,0.8,0.9),...) UseMethod("postprob")
